/**
 * This is a simple web app server for AlmostBook. It uses the HttpServer
 * library from angularjs and is under the same license.
 *
 * @author Elliott Sprehn (esprehn@gmail.com)
 * @see https://github.com/angular/angular.js/blob/master/lib/nodeserver/server.js
 */

var sys = require('sys'),
  HttpServer = require('http_server').HttpServer,
  StaticServlet = require('static_servlet').StaticServlet,
  fs = require('fs');

var DEFAULT_PORT = 8000;

var staticServlet = new StaticServlet();
var defaultHandler = staticServlet.handleRequest.bind(staticServlet);

function handleRequest(req, res) {
  var pathname = req.url.pathname;
  if (pathname === '/') {
    req.url.pathname = '/index.html';
  }
  (routes[req.url.pathname] || defaultHandler)(req, res);
};

function compare(value, expected) {
  if (!expected) return true;
  return value.toLowerCase().indexOf(expected.toLowerCase()) !== -1;
}

function loadJson(path, callback) {
  fs.readFile(path, function(err, data) {
    try {
      callback(JSON.parse(data));
    } catch (e) {
      sys.puts('Invalid JSON: ' + e);
      callback([]);
    }
  });
}

var routes = {
  '/friends': function(req, res) {
    var query = req.url.query;
    res.writeHead(200, {
      'Content-Type': 'application/json'
    });
    loadJson('lib/nodeserver/friends.json', function(friends) {
      res.write(JSON.stringify(friends.filter(function(friend) {
        if (query.name && !compare(friend.name, query.name)) {
          return false;
        }
        return compare(friend.name, query.search) ||
          compare(friend.website, query.search);
      }).sort(function(a, b) {
        return a.name.localeCompare(b.name);
      })));
      res.end();
    });
  },

  '/feed': function(req, res) {
    var query = req.url.query;
    var friendIds = (query.friends || '').split(',').filter(function(value) {
      return value.length;
    }).map(function(value) {
      return Number(value);
    });
    res.writeHead(200, {
      'Content-Type': 'application/json'
    });
    loadJson('lib/nodeserver/feed.json', function(feed) {
      res.write(JSON.stringify(feed.filter(function(item) {
        return !friendIds.length || friendIds.indexOf(item.user) !== -1;
      }).sort(function(a, b) {
        return Date.parse('2011 ' + b.time) - Date.parse('2011 ' + a.time);
      })));
      res.end();
    });
  }

};

new HttpServer({
  'GET': handleRequest
}).start(Number(process.argv[2]) || DEFAULT_PORT);
