/**
 * XHR service that wraps up jQuery XHR so we can mock it out in tests.
 *
 * @author Elliott Sprehn (esprehn@gmail.com)
 */
function XhrService() {
}

/**
 * Performs a simple XHR.
 *
 * @param {string} method HTTP method.
 * @param {string} url URL to request.
 * @param {Object} data Object to be serialized and sent.
 * @param {Function} callback Function call when the response comes back.
 * @param {Object} opt_self optional context to call the callback with.
 */
XhrService.prototype.send = function(method, url, data, callback, opt_self) {
  $.ajax({
    url: url,
    method: method,
    data: data,
    success: function() {
      callback.apply(opt_self, arguments);
    },
  });
};

/**
 * Perform a GET request.
 *
 * @param {string} url URL to request.
 * @param {Function} callback Function call when the response comes back.
 * @param {Object} opt_self optional context to call the callback with.
 */
XhrService.prototype.get = function(url, callback, opt_self) {
  this.send('GET', url, undefined, callback, opt_self);
};

/**
 * Perform a GET request.
 *
 * @param {string} url URL to request.
 * @param {Object} data Object to be serialized and sent.
 * @param {Function} callback Function call when the response comes back.
 * @param {Object} opt_self optional context to call the callback with.
 */
XhrService.prototype.post = function(url, data, callback, opt_self) {
  this.send('POST', url, data, callback, opt_self);
};
