/**
 * Mock XHR service for testing.
 *
 * @author Elliott Sprehn (esprehn@gmail.com)
 */
function MockXhrService() {
  this.requests = [];
}
MockXhrService.prototype = new XhrService();

/**
 * @inheritDoc
 */
MockXhrService.prototype.send = 
    function(method, url, data, callback, opt_self) {
  var request = _(this.requests).find(function(item) {
    return item.url === url &&
      item.method === method &&
      _(item.data).isEqual(data);
  });
  if (!request) {
    throw new Error('Unexpected XHR request for url ' + url);
  }
  request.callback = callback;
  request.self = opt_self || window;
};

/**
 * Lets you expect an XHR request. ex.
 *
 *   service.
 *     expect('POST', '/users/1/update', {username: 'Elliott'})
 *     respond({success: true});
 *
 * @param {string} method HTTP method.
 * @param {string} url URL to request.
 * @param {Object} data Object to be serialized and sent.
 * @return {{respond: function(Object)}} Object with respond(Object) method.
 */
MockXhrService.prototype.expect = function(method, url, data) {
  var requests = this.requests;
  return {
    respond: function(result) {
      requests.push({
        url: url,
        method: method,
        data: data,
        result: result
      });
    }
  };
};

/**
 * Causes all pending XHR requests to return.
 */
MockXhrService.prototype.flush = function() {
  this.requests = _(this.requests).filter(function(item) {
    if (item.callback) {
      item.callback.call(item.self, item.result);
      return false;
    }
    return true;
  });
};
