/**
 * Tests written with JSTD for the ProfileController in AlmostBook.
 *
 * @author Elliott Sprehn (esprehn@gmail.com)
 */

ProfileControllerTest = TestCase('ProfileControllerTest');

ProfileControllerTest.prototype.setUp = function() {
  this.xhr = new MockXhrService();
  this.controller = new ProfileController(this.xhr);
};

ProfileControllerTest.prototype.testLoadFriendsDefaultIsAllFriends =
    function() {
  var friends = [
    {id: 1, name: 'Mark Drew'},
    {id: 1, name: 'Simon Free'}
  ];
  this.xhr.expect('GET', '/friends').respond(friends);
  this.controller.loadFriends();
  this.xhr.flush();
  assertEquals(friends, this.controller.friends);
};

ProfileControllerTest.prototype.testLoadFriendsWithFilter = function() {
  var friends = [
    {id: 1, name: 'Mark Drew'}
  ];
  this.xhr.expect('GET', '/friends?search=Mark').respond(friends);
  this.controller.loadFriends('Mark');
  this.xhr.flush();
  assertEquals(friends, this.controller.friends);
};


ProfileControllerTest.prototype.testLoadFriendsKeywordParam = function() {
  var friends = [
    {id: 1, name: 'Mark Drew'}
  ];
  this.xhr.expect('GET', '/friends?user=1').respond(friends);
  this.controller.loadFriends('user:1');
  this.xhr.flush();
  assertEquals(friends, this.controller.friends);
};

ProfileControllerTest.prototype.testLoadFriendsKeywordParamWithQuotes =
    function() {
  var friends = [
    {id: 1, name: 'Sean Corfield'}
  ];
  this.xhr.expect('GET', '/friends?user=Sean%20Corfield').respond(friends);
  this.controller.loadFriends('user:"Sean Corfield"');
  this.xhr.flush();
  assertEquals(friends, this.controller.friends);
};

ProfileControllerTest.prototype.testLoadFeedOnlyLoadedFriends = function() {
  var friends = [
    {id: 2, name: 'Debbie Flax'},
    {id: 1, name: 'Mark Drew'}
  ];
  var feed = [
    {user: 2, text: 'This is way better than the RealBook', time: '12:00'},
    {user: 1, text: 'Testing is awesome!', time: '12:15'},
  ];
  this.xhr.expect('GET', '/friends').respond(friends);
  this.xhr.expect('GET', '/feed?friends=2,1').respond(feed);
  this.controller.loadFriends();
  this.xhr.flush();
  assertEquals([], this.controller.feed);
  this.controller.loadFeed();
  this.xhr.flush();
  assertEquals(friends, this.controller.friends);
  assertEquals(feed, this.controller.feed);
};
