/**
 * Tests written with Jasmine for the Profiles in AlmostBook.
 *
 * @author Elliott Sprehn (esprehn@gmail.com)
 */

describe('Profiles', function() {
  var xhr, controller;

  beforeEach(function() {
    xhr = new MockXhrService();
    controller = new ProfileController(xhr);
  });

  it('should load all friends on first page load', function() {
    var friends = [
      {id: 1, name: 'Mark Drew'},
      {id: 1, name: 'Simon Free'}
    ];
    xhr.expect('GET', '/friends').respond(friends);
    controller.loadFriends();
    xhr.flush();
    expect(controller.friends).toEqual(friends);
  });

  describe('friend filtering', function() {
    var friends = [
      {id: 1, name: 'Mark Drew'}
    ];

    it('should allow filtering friends by name', function() {
      xhr.expect('GET', '/friends?search=Mark').respond(friends);
      controller.loadFriends('Mark');
      xhr.flush();
      expect(controller.friends).toEqual(friends);
    });

    it('should allow colon keyword searches', function() {
      xhr.expect('GET', '/friends?user=1').respond(friends);
      controller.loadFriends('user:1');
      xhr.flush();
      expect(controller.friends).toEqual(friends);
    });

    it('should allow quotes in colon keyword search values', function() {
      xhr.expect('GET', '/friends?user=Mark%20Drew').respond(friends);
      controller.loadFriends('user:"Mark Drew"');
      xhr.flush();
      expect(controller.friends).toEqual(friends);
    });
  });

  describe('feed', function() {
    var friends = [
      {id: 2, name: 'Debbie Flax'},
      {id: 1, name: 'Mark Drew'}
    ];
    var feed = [
      {user: 2, text: 'This is way better than the RealBook', time: '12:00'},
      {user: 1, text: 'Testing is awesome!', time: '12:15'},
    ];
    it('should load posts from filtered friends', function() {
      xhr.expect('GET', '/friends').respond(friends);
      xhr.expect('GET', '/feed?friends=2,1').respond(feed);
      controller.loadFriends();
      xhr.flush();
      expect(controller.feed).toEqual([]);
      controller.loadFeed();
      xhr.flush();
      expect(controller.friends).toEqual(friends);
      expect(controller.feed).toEqual(feed);
    });
  });

});
